@@ -23,6 +23,7 @@ from pypika import JoinType, Parameter, Query, Table
 from pypika.terms import ArithmeticExpression, Function
 
 from tortoise.exceptions import OperationalError
+from tortoise.expressions import F
 from tortoise.fields.base import Field
 from tortoise.fields.relational import (
     BackwardFKRelation,
@@ -209,29 +210,43 @@ class BaseExecutor:
             ]
             await self.db.execute_insert(self.insert_query_all, values)
 
-    async def execute_bulk_insert(self, instances: "Iterable[Model]") -> None:
-        values_lists_all = []
-        values_lists = []
-        for instance in instances:
-            if instance._custom_generated_pk:
-                values_lists_all.append(
-                    [
-                        self.column_map[field_name](getattr(instance, field_name), instance)
-                        for field_name in self.regular_columns_all
-                    ]
-                )
-            else:
-                values_lists.append(
-                    [
-                        self.column_map[field_name](getattr(instance, field_name), instance)
-                        for field_name in self.regular_columns
-                    ]
-                )
+    @staticmethod
+    def _chunk(instances: "Iterable[Model]", batch_size: Optional[int] = None):
+        if not batch_size:
+            yield instances
+        else:
+            instances = list(instances)
+            for i in range(0, len(instances), batch_size):
+                yield instances[i : i + batch_size]  # noqa:E203
 
-        if values_lists_all:
-            await self.db.execute_many(self.insert_query_all, values_lists_all)
-        if values_lists:
-            await self.db.execute_many(self.insert_query, values_lists)
+    async def execute_bulk_insert(
+        self,
+        instances: "Iterable[Model]",
+        batch_size: Optional[int] = None,
+    ) -> None:
+        for instance_chunk in self._chunk(instances, batch_size):
+            values_lists_all = []
+            values_lists = []
+            for instance in instance_chunk:
+                if instance._custom_generated_pk:
+                    values_lists_all.append(
+                        [
+                            self.column_map[field_name](getattr(instance, field_name), instance)
+                            for field_name in self.regular_columns_all
+                        ]
+                    )
+                else:
+                    values_lists.append(
+                        [
+                            self.column_map[field_name](getattr(instance, field_name), instance)
+                            for field_name in self.regular_columns
+                        ]
+                    )
+
+            if values_lists_all:
+                await self.db.execute_many(self.insert_query_all, values_lists_all)
+            if values_lists:
+                await self.db.execute_many(self.insert_query, values_lists)
 
     def get_update_sql(
         self,
@@ -253,11 +268,14 @@ class BaseExecutor:
             db_column = self.model._meta.fields_db_projection[field]
             field_object = self.model._meta.fields_map[field]
             if not field_object.pk:
-                if db_column not in arithmetic_or_function.keys():
+                if field not in arithmetic_or_function.keys():
                     query = query.set(db_column, self.parameter(count))
                     count += 1
                 else:
-                    query = query.set(db_column, arithmetic_or_function.get(db_column))
+                    value = F.resolver_arithmetic_expression(
+                        self.model, arithmetic_or_function.get(field)
+                    )[0]
+                    query = query.set(db_column, value)
 
         query = query.where(table[self.model._meta.db_pk_column] == self.parameter(count))
 
